# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from landing_page_server_connector.models.optin_method import OptinMethod

class FormGet(BaseModel):
    """
    FormGet
    """
    landing_id: StrictInt = Field(...)
    opt_in_process_id: Optional[StrictInt] = None
    uuid: StrictStr = Field(...)
    opt_in_method: OptinMethod = Field(...)
    id: StrictInt = Field(...)
    created_at: StrictInt = Field(...)
    updated_at: Optional[StrictInt] = None
    deleted_at: Optional[StrictInt] = None
    __properties = ["landing_id", "opt_in_process_id", "uuid", "opt_in_method", "id", "created_at", "updated_at", "deleted_at"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FormGet:
        """Create an instance of FormGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FormGet:
        """Create an instance of FormGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FormGet.parse_obj(obj)

        _obj = FormGet.parse_obj({
            "landing_id": obj.get("landing_id"),
            "opt_in_process_id": obj.get("opt_in_process_id"),
            "uuid": obj.get("uuid"),
            "opt_in_method": obj.get("opt_in_method"),
            "id": obj.get("id"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "deleted_at": obj.get("deleted_at")
        })
        return _obj


